@@ -22,14 +22,11 @@
 ;;;; Declare the suites
 (suite 'make-check
        '(executable ieee-fp eprocess package-ext hash-tables ansi+ mixed
-         cmp emb ffi mop run-program mp complex))
+         cmp emb ffi mop run-program mp complex #+unicode unicode))
 
 (suite 'ecl-tests
        '(make-check eformat))
 
-(suite 'stress)
-(test stress.all (finishes (1am-ecl:run)))
-
 
 (defmacro is-true (form)
   (ext:once-only (form)
@@ -92,10 +89,12 @@ allow using reader macros. The output is stored in a string and output
 as a second value."
   `(progn
      (with-open-file (s ,filename :direction :output :if-exists :supersede
-                        :if-does-not-exist :create)
-       ,@(loop for f in forms collect (if (stringp f)
-                                          `(format s "~A" ,f)
-                                          `(print ,f s))))
+                                  :if-does-not-exist :create)
+       (let ((*print-circle* t)
+             (*print-readably* t))
+         ,@(loop for f in forms collect (if (stringp f)
+                                            `(format s "~A" ,f)
+                                            `(print ,f s)))))
      (let* ((compiled-file t)
             (output
              (with-output-to-string (*standard-output*)
